@@ -7,8 +7,7 @@ from xync_schema.xtype import BaseAd
 
 from xync_client.Abc.BaseTest import BaseTest
 from xync_schema.enums import ExStatus, ExType, ExAction
-from xync_schema.models import Ex, ExStat, Curex, Coinex
-
+from xync_schema import models
 from xync_client.Abc.Ex import BaseExClient
 from xync_client.loader import TOKEN
 
@@ -17,8 +16,8 @@ from xync_client.loader import TOKEN
 class TestEx(BaseTest):
     @pytest.fixture
     async def clients(self) -> list[HttpClient]:
-        exs = await Ex.filter(status__gt=ExStatus.plan).prefetch_related("pm_reps")
-        [await ex for ex in exs if ex.type_ == ExType.tg]
+        exs = await models.Ex.filter(status__gt=ExStatus.plan).prefetch_related("pm_reps")
+        [await ex for ex in exs if ex.typ == ExType.tg]
         async with FileClient(TOKEN) as b:
             b: FileClient
             clients: list[BaseExClient] = [ex.client(b) for ex in exs]
@@ -29,25 +28,33 @@ class TestEx(BaseTest):
     async def test_set_coins(self, clients: list[BaseExClient]):
         for client in clients:
             await client.set_coins()
-            t, _ = await ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_coins)
+            t, _ = await models.ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_coins)
             assert t.ok, "Coins not set"
-            logging.info(f"{client.ex.name}: {ExAction.ads.name} - ok")
+            logging.info(f"{client.ex.name}: {ExAction.set_coins.name} - ok")
+
+    # 0
+    async def test_set_curs(self, clients: list[BaseExClient]):
+        for client in clients:
+            await client.set_curs()
+            t, _ = await models.ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_curs)
+            assert t.ok, "Curs not set"
+            logging.info(f"{client.ex.name}: {ExAction.set_curs.name} - ok")
 
     # 0
     async def test_set_pms(self, clients: list[BaseExClient]):
         for client in clients:
             await client.set_pms()
-            t, _ = await ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_pms)
-            assert t.ok, "PmCurs not set"
-            logging.info(f"{client.ex.name}: {ExAction.ads.name} - ok")
+            t, _ = await models.ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_pms)
+            assert t.ok, "Pms not set"
+            logging.info(f"{client.ex.name}: {ExAction.set_pms.name} - ok")
 
     # 0
-    # async def test_set_pairs(self, clients: list[BaseExClient]):
-    #     for client in clients:
-    #         await client.set_pairs()
-    #         t, _ = await ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_pairs)
-    #         assert t.ok, "Pairs not set"
-    #         logging.info(f"{client.ex.name}: {ExAction.ads.name} - ok")
+    async def test_set_pairs(self, clients: list[BaseExClient]):
+        for client in clients:
+            await client.set_pairs()
+            t, _ = await models.ExStat.update_or_create({"ok": True}, ex=client.ex, action=ExAction.set_pairs)
+            assert t.ok, "Pairs not set"
+            logging.info(f"{client.ex.name}: {ExAction.set_pairs.name} - ok")
 
     # # 19
     # async def test_curs(self, clients: list[BaseExClient]):
@@ -97,10 +104,38 @@ class TestEx(BaseTest):
     # 24
     async def test_ads(self, clients: list[BaseExClient]):
         for client in clients:
-            cur = await Curex.filter(cur__ticker="EUR", ex=client.ex).first().values_list("exid", flat=True)
-            coin = await Coinex.filter(coin__ticker="USDT", ex=client.ex).first().values_list("exid", flat=True)
+            cur = await models.CurEx.filter(cur__ticker="EUR", ex=client.ex).first().values_list("exid", flat=True)
+            coin = await models.CoinEx.filter(coin__ticker="USDT", ex=client.ex).first().values_list("exid", flat=True)
             ads: list[BaseAd] = await client.ads(coin, cur, False)
             ok = self.is_list_of_objects(ads, BaseAd)
-            t, _ = await ExStat.update_or_create({"ok": ok}, ex=client.ex, action=ExAction.ads)
+            t, _ = await models.ExStat.update_or_create({"ok": ok}, ex=client.ex, action=ExAction.ads)
             assert t.ok, "No ads"
             logging.info(f"{client.ex.name}: {ExAction.ads.name} - ok")
+
+    async def test_race(self, clients: list[BaseExClient]):
+        races: list[models.Race] = await models.Race.filter(started=True).prefetch_related(
+            "road__ad__pair_side__pair", "road__ad__maker", "road__ad__pms"
+        )
+        ex_ids: set = {race.road.ad.maker.ex_id for race in races}
+        errors: dict[int, int | None] = {}
+        for client in clients:
+            if client.ex.id not in ex_ids:
+                continue
+            for race in races:
+                # получаем данные направления текущей гонки
+                coinex = await models.CoinEx.get(ex=client.ex, coin_id=race.road.ad.pair_side.pair.coin_id)
+                curex = await models.CurEx.get(ex=client.ex, cur_id=race.road.ad.pair_side.pair.cur_id)
+                pm_ids = [pm.id for pm in race.road.ad.pms]
+                pmex_exids = await models.PmEx.filter(ex=client.ex, pm_id__in=pm_ids).values_list("exid", flat=True)
+                # получаем объявления по этому направлению
+                ads = await client.ads(coinex.exid, curex.exid, race.road.ad.pair_side.is_sell, pmex_exids)
+                # if race.vm_filter:
+                #     ads = [ad for ad in ads if "VA" in ad.authTag]
+                # client.overprice_filter(ads, race.ceil, k)  # обрезаем сверху все ads дороже нашего потолка
+                # определяем место нашего объявления в списке
+                places = [i for i, ad in enumerate(ads) if int(ad.userId) == race.road.ad.maker.exid]
+                if not places:
+                    errors[race.id] = None
+                elif places[0] != race.target_place:
+                    errors[race.id] = places[0]
+        assert not errors, "Гонка " + ", ".join(f"#{rid} на {plc} месте" for rid, plc in errors.items())
