@@ -14,7 +14,6 @@ from xync_client.loader import TORM
 
 
 class ExClient(BaseExClient):  # Bybit client
-    host = "api2.bybit.com"
     headers = {"cookie": ";"}  # rewrite token for public methods
     agent: Agent = None
 
@@ -38,10 +37,7 @@ class ExClient(BaseExClient):  # Bybit client
     # 20: Список платежных методов
     async def pms(self, cur: models.Cur = None) -> dict[int | str, PmEx]:
         self.session.cookie_jar.update_cookies(await self._get_auth_cks())
-        pms = await self._post(
-            "/fiat/otc/configuration/queryAllPaymentList/",
-        )
-        # self.session.cookie_jar.clear(lambda x: x.key == "secure-token")
+        pms = await self._post("/fiat/otc/configuration/queryAllPaymentList/")
         self.session.cookie_jar.clear()
 
         pms = pms["result"]["paymentConfigVo"]
@@ -49,6 +45,7 @@ class ExClient(BaseExClient):  # Bybit client
 
     # 21: Список платежных методов по каждой валюте
     async def cur_pms_map(self) -> MapOfIdsList:
+        self.session.cookie_jar.update_cookies(await self._get_auth_cks())
         pms = await self._post("/fiat/otc/configuration/queryAllPaymentList/")
         return json.loads(pms["result"]["currencyPaymentIdMap"])
 
@@ -58,7 +55,7 @@ class ExClient(BaseExClient):  # Bybit client
         coinexs = {}
         for c in config["symbols"]:
             coinexs[c["tokenId"]] = xtype.CoinEx(
-                exid=c["tokenId"], ticker=c["tokenId"], minimum=c["currencyMinQuote"], scale=c["token"]["scale"]
+                exid=c["tokenId"], ticker=c["tokenId"], minimum=c["tokenMinQuote"], scale=c["token"]["scale"]
             )
         return coinexs
 
@@ -78,7 +75,8 @@ class ExClient(BaseExClient):  # Bybit client
         is_sell: bool,
         pm_exids: list[str | int] = None,
         amount: int = None,
-        lim: int = None,
+        lim: int = 50,
+        vm_filter: bool = False,
     ) -> list[ad.Ad]:
         data = {
             "userId": "",
@@ -86,12 +84,29 @@ class ExClient(BaseExClient):  # Bybit client
             "currencyId": cur_exid,
             "payment": pm_exids or [],
             "side": "0" if is_sell else "1",
-            "size": lim and str(lim) or "200",
+            "size": str(lim) if lim else "20",
             "page": "1",
             "amount": str(amount) if amount else "",
-            "authMaker": False,
+            "vaMaker": vm_filter,
+            "bulkMaker": False,
             "canTrade": False,
+            "verificationFilter": 0,
+            "sortType": "OVERALL_RANKING",
+            "paymentPeriod": [],
+            "itemRegion": 1,
         }
+        # {
+        #     "userId": "",
+        #     "tokenId": coin_exid,
+        #     "currencyId": cur_exid,
+        #     "payment": pm_exids or [],
+        #     "side": "0" if is_sell else "1",
+        #     "size": lim and str(lim) or "200",
+        #     "page": "1",
+        #     "amount": str(amount) if amount else "",
+        #     "authMaker": False,
+        #     "canTrade": False,
+        # }
         ads = await self._post("/fiat/otc/item/online/", data)
         return [ad.Ad(**_ad) for _ad in ads["result"]["items"]]
 
@@ -102,7 +117,7 @@ async def main():
     bot: FileClient = FileClient(TOKEN)
     # await bot.start()
     cl = ExClient(ex, bot)
-    await cl.set_pms()
+    # await cl.set_pms()
     await cl.set_coins()
     await cl.set_pairs()
     _ads = await cl.ads("USDT", "GEL", False)
