@@ -1,10 +1,5 @@
-import re
-import subprocess
-from asyncio import run, sleep
-from json import loads
-
+from asyncio import run
 import requests
-from bs4 import BeautifulSoup, Script
 from pyro_client.client.file import FileClient
 from x_model import init_db
 from xync_schema.models import Ex
@@ -19,27 +14,23 @@ from xync_client.Gate.etype import ad
 class ExClient(BaseExClient):
     logo_pre_url = "www.gate.io"
 
+    _data: dict = {}
+
     # Данные для р2р из html Gate.io
-    async def c2c_data(self) -> dict:
-        await sleep(1)
-        # doc = await self._get("/p2p")  # todo: почему не работает? хз
-        doc = requests.get("https://www.gate.io/p2p").text
-        await sleep(1)
-        soup = BeautifulSoup(doc, "html.parser")
-        script: Script = soup.find_all("script", string=re.compile("var c2cData"))[0]  # todo: refact: 23-th not stable
-        strng = script.get_text().replace("  ", "")
-        pattern = r"var c2cData = (\{.*?\})\s+var transLang"
-        match = re.search(pattern, strng.replace(",}", "}").replace(",]", "]"), re.DOTALL)
-        res = match.group(1)
-        with open("res.js", "w") as file:
-            file.write(f"const lang_string = a => a;console.log(JSON.stringify({res}))")
-        p = subprocess.Popen(["node", "res.js"], stdout=subprocess.PIPE)
-        out = p.stdout.read().decode()
-        return loads(out)
+    @property
+    def data(self) -> (dict, dict, dict, dict):
+        self._data = (
+            self._data
+            or requests.post(
+                "https://www.gate.com/json_svr/query_push?u=p2p_common_trade_config",
+                data={"type": "p2p_common_trade_config"},
+            ).json()["datas"]
+        )
+        return self._data
 
     # 20: Список всех платежных методов на бирже
     async def pms(self, cur: str = None) -> dict[int | str, PmEx]:
-        data = await self.c2c_data()
+        data = self.data
         return {
             p["pay_type"]: PmEx(exid=p["pay_type"], name=p["pay_name"], logo=p["image"])
             for p in (data["payment_settings"]).values()
@@ -47,12 +38,12 @@ class ExClient(BaseExClient):
 
     # 21: Список поддерживаемых валют
     async def coins(self) -> dict[xtype.CoinEx]:
-        data = await self.c2c_data()
-        return {coin: xtype.CoinEx(exid=coin, ticker=coin) for coin in data["cryptoList"]}
+        data = self.data
+        return {coin: xtype.CoinEx(exid=coin, ticker=coin) for coin in data["c2c_currencies"]}
 
     # 22: Списки поддерживаемых платежек по каждой валюте
     async def cur_pms_map(self) -> MapOfIdsList:
-        data = await self.c2c_data()
+        data = self.data
         return data["fait_payment_settings"]
 
     async def pairs(self) -> MapOfIdsList:
@@ -63,8 +54,8 @@ class ExClient(BaseExClient):
 
     # 23: Монеты на Gate
     async def curs(self) -> dict[xtype.CurEx]:
-        data = await self.c2c_data()
-        return {cur: xtype.CurEx(exid=cur, ticker=cur) for cur in data["fiatList"]}
+        data = self.data
+        return {cur: xtype.CurEx(exid=cur, ticker=cur) for cur in data["c2c_fiats"]}
 
     # 24: ads
     async def ads(
@@ -96,10 +87,13 @@ async def main():
     gt = await Ex.get(name="Gate")
     async with FileClient(TOKEN) as b:
         cl = ExClient(gt, b)
+        await cl.set_pairs()
+        pms = await cl.set_coins()
+        pms = await cl.set_curs()
+        pms = await cl.set_pms()
         _ads = await cl.ads("USDT", "RUB", True, ["payeer"], 1000)
         # curs = await cl.curs()
         # await cl.coins()
-        pms = await cl.set_pmcurs()
         print(pms)
 
 
