@@ -24,7 +24,7 @@ class ExClient(BaseExClient):
 
     _data: dict = {}
 
-    def pm_type_map(self, typ: models.Pmex) -> str:
+    def pm_type_map(self, typ: models.PmEx) -> str:
         pass
 
     async def pairs(self) -> tuple[MapOfIdsList, MapOfIdsList]:
