@@ -20,12 +20,12 @@ class PmUnifier:
         r"^bank (?!of )|bank$",
         r" banka$",
         r" bankas$",
-        r" bankası$",
+        r" bankasi$",
         r" banca$",
         r"^banco(?! de | del )| banco$",
     ]
     re_extra = [
-        r"\(card\)$|\bpay$|\bmoney$|\bwallet$|\bcash$|\bmobile$|\bapp$|\blightning$",
+        r"\(card\)$|\bpay$|\bmoney$|\be?wallet\b|\bcash$|\bmobile$|\bapp$|\blightning$",
         r"b\.s\.c\.|k\.s\.c|s\.a\.a\.?$|s\.a\.?$| sv$| gt$",
     ]
     re_glut = [
@@ -33,7 +33,8 @@ class PmUnifier:
         r"l'|d’|d′|d'",
     ]
     i18n_map = {
-        " - ": "-",
+        " -": "-",
+        "- ": "-",
         " & ": "&",
         "nationale": "national",
         "а": "a",
@@ -60,26 +61,38 @@ class PmUnifier:
         "ň": "n",
     }
     rms = ":`'’′"
-    frz = {"Cash App", "Cash app", "Cash Wallet", "Mobile Pay", "Nepal QR", "Pay Pay", "QRIS lightning"}
+    frz = {
+        "cash app",
+        "cash wallet",
+        "mobile Pay",
+        "nepal qr",
+        "pay pay",
+        "qris lightning",
+        "au pay",
+        "mobile pay",
+        # "yemen kuwait bank", "nepal bank", "jordan kuwait bank", "chinabank", "nepal bangladesh bank", "belarusbank"
+    }
 
     def __init__(self, countries: list[tuple[str, str]], pm_reps: list[PmRep]):
-        self.pm_map = {p.src: p.trgt for p in pm_reps}
+        self.pm_map = {p.src: p.target for p in pm_reps}
         self.cts = countries
 
     def countries(self, name: str):
         for ct, st in self.cts:
             # Если имя кончается на "Название_страны" (мб в скобках)
-            if match := re.search(re.compile(rf"\({ct}\)|\b{ct}\b"), self.pms[name].norm):
+            if match := re.search(re.compile(rf"\({ct}\)|\b{ct}$"), self.pms[name].norm):
                 # if name.endswith((ct + ")", ct)):
                 if (
                     not self.pms[name].norm.endswith((" of " + ct, " of the " + ct, " and " + ct, " de " + ct))
-                    and name not in self.frz
+                    and name.lower() not in self.frz
                 ):
                     self.pms[name].norm = self.pms[name].norm.replace(match.group(), "")
                     self.clear(name)
                 self.pms[name].country = ct
                 return
-            elif match := re.search(re.compile(rf"\s?\({st}\)|\b{st}$"), self.pms[name].norm):
+            elif match := re.search(re.compile(rf"\s?\({st}\)$|\b{st}$"), self.pms[name].norm):
+                if not self.pms[name].norm.endswith(" of " + st):
+                    ...
                 self.pms[name].norm = self.pms[name].norm.replace(match.group(), "")
                 self.pms[name].country = ct
                 return
@@ -87,7 +100,7 @@ class PmUnifier:
     def extra(self, name: str):
         for r in self.re_extra:
             if match := re.search(r, self.pms[name].norm):
-                if name not in self.frz:
+                if name.lower() not in self.frz:
                     self.pms[name].norm = self.pms[name].norm.replace(match.group(), "")
                 self.pms[name].extra = match.group()
                 self.clear(name)
@@ -129,7 +142,7 @@ class PmUnifier:
         if len(acr) >= 2 and (
             f"({acr})" in self.pms[name].norm
             or self.pms[name].norm.startswith((acr + " ", acr + ":"))
-            or self.pms[name].norm.endswith(" " + acr)
+            or self.pms[name].norm.endswith((" " + acr, "-" + acr))
         ):
             self.pms[name].norm = self.pms[name].norm.replace(acr, "", 1)
             self.pms[name].acronym = acr
@@ -140,16 +153,14 @@ class PmUnifier:
             self.pms[name].norm = re.sub(rm, "", self.pms[name].norm)
 
     def i18n(self, name: str):
-        for src, trgt in self.i18n_map.items():
-            self.pms[name].norm = self.pms[name].norm.replace(src, trgt)
+        for src, target in self.i18n_map.items():
+            self.pms[name].norm = self.pms[name].norm.replace(src, target)
 
     def clear(self, name: str):
         self.pms[name].norm = self.pms[name].norm.replace("()", "").replace("  ", " ").strip(" -:.	")
 
     def __call__(self, s: str) -> PmUni:
         # если в словаре замен есть текущее назвние - меняем, иначе берем строку до запятой
-        if s.startswith("m "):
-            ...
         self.pms[s] = PmUni(norm=self.pm_map.get(s, s.split(",")[0]))
         # вырезаем мусорные добавки
         self.slim(s)
